base_extras
==================================================
**Module**: :mod:`espressodb.base.templatetags.base_extras`


.. currentmodule:: espressodb.base.templatetags.base_extras

.. autosummary::
    render_link_list
    render_field
    render_fields
    render_tree
    render_version
    render_db_info
    project_name

------

.. automodule:: espressodb.base.templatetags.base_extras
    :members:
    :special-members:
